<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>ཡིག་ཆ་དོ་དམ་ཆས་ཁྲོད་དུ་མངོན་པ།</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>ཉིན་ཐོ་སུབ་པ།</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>གསར་འདོན།</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>ཁྱེད་ཀྱིས་ཉིན་ཐོ་འདི་སུབ་རྒྱུ་གཏན་ཁེལ་ལམ།</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>འདོར་བ།</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>གཏན་འཁེལ།</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>ཚང་མ།</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>དེ་རིང་།</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>ཉེ་བའི་ཉིན་3</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>ཉེ་བའི་གཟའ་1</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>ཉེ་བའི་ཟླ་1</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>ཉེ་བའི་ཟླ་3</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>ཕྱིར་འདྲེན།</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>ཚང་མ།</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>ཛ་དྲག</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>ཚབས་ཆེའི་ཉེན་བརྡ།</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>ཚབས་ཆེན། </translation>
    </message>
    <message>
        <source>Error</source>
        <translation>ནོར་འཁྲུལ། </translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>ཉེན་བརྡ། </translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>དོ་སྣང་།</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>ཆ་འཕྲིན། </translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>སྙོམ་སྒྲིག</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>ཐོ་འཇུག</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>འཕྲུལ་སྒོ་འབྱེད།</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>འཕྲུལ་སྒོ་རྒྱག</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>ཚབས་ལྕི་བ།</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>རྗེས་སྙེག</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>ཐོབ་ཐང་དབྱེ་འབྱེད།</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>རང་བདག་ལྟ་སྤྱོད་ཚོད་འཛིན།</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>བཙན་ཤེད་ཀྱིས་ལྟ་སྤྱོད་ཚོད་འཛིན་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>རྒྱང་སྦྲེལ།</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>ཡིག་ཆ་རྩིས་བཤེར།</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>གཞན།</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation>zip(*.zip)</translation>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>ཕྱིར་འདྲེན་བཞིན་པ། </translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>འདོར་བ།</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>ཕྱིར་འདྲེན་ཐུབ་སོང་།</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>འདོན་མི་ཐུབ།</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation>ཕྱིར་དྲངས་པའི་དཀར་ཆག་སྤྱོད་མི་རུང་། དཀར་ཆག་གཞན་བདམས་ནས་བཀོལ་སྤྱོད་བྱེད་རོགས།</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>ཡིག་ཆ་ཕྱིར་འདྲེན། </translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>དུས་འཁོར། </translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>རིམ་པ། </translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>ངང་ཚུལ།</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>བྱ་བའི་རིགས་ཁག</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>གཙོ་འཕྲུལ་མིང་།</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>བྱ་རིམ་ཨང་རྟགས།</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>བྱ་འགུལ། </translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>སྤྱོད་མཁན། </translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>འཕྲུལ་སྒོ་འབྱེད་པའི་ཐོ། </translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>འཕྲུལ་སྒོ་རྒྱག་པའི་ཐོ། </translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>ཐོ་འཇུག་ཆ་འཕྲིན། </translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>རྩིས་བཤེར་རིགས།</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation>ཉེར་སྤྱོད།</translation>
    </message>
    <message>
        <source>Submodule:</source>
        <translation>བུ་ཆའི་མ་དཔེ།</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>ཉེན་བརྡ། </translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>སྙོམ་སྒྲིག</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>ཆ་འཕྲིན། </translation>
    </message>
    <message>
        <source>Error</source>
        <translation>ནོར་འཁྲུལ། </translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>ཛ་དྲག</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>ཚབས་ཆེའི་ཉེན་བརྡ།</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>ཚབས་ཆེན། </translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>དོ་སྣང་།</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>རྗེས་སྙེག</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>ཚབས་ལྕི་བ།</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>ཉིན་ཐོའི་ཡིག་ཆ་སྟོང་པ་རེད་འདུག</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>ཉིན་ཐོ་འཚོལ་སྡུད་ཡོ་བྱད།</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>ཉིན་ཐོ་འཚོལ་སྡུད་ཡོ་བྱད་ནི་མ་ལག་ཉིན་ཐོ་འཚོལ་བཤེར་བྱེད་པའི་ཡོ་བྱད་ཆུང་ཆུང་ཞིག་རེད།</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>འཚོལ་བཤེར་འབྲས་བུ་མེད། </translation>
    </message>
    <message>
        <source>Search</source>
        <translation>འཚོལ་བཤེར།</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>རིམ་པ། </translation>
    </message>
    <message>
        <source>Process</source>
        <translation>བྱ་རིམ། </translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>དུས་ཚོད། </translation>
    </message>
    <message>
        <source>Info</source>
        <translation>ཆ་འཕྲིན། </translation>
    </message>
    <message>
        <source>User</source>
        <translation>གཙོ་འཕྲུལ་མིང་།</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>བྱ་རིམ་ཨང་རྟགས། </translation>
    </message>
    <message>
        <source>Source</source>
        <translation>ཡོང་ཁུངས། </translation>
    </message>
    <message>
        <source>Action</source>
        <translation>བྱ་འགུལ། </translation>
    </message>
    <message>
        <source>Status</source>
        <translation>ངང་ཚུལ།</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>བྱ་བའི་རིགས་ཁག</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>སྤྱོད་མཁན། </translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>རིམ་པ། </translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>བྱ་རིམ། </translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>དུས་ཚོད། </translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>ཆ་འཕྲིན། </translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>གཙོ་འཕྲུལ་མིང་།</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>བྱ་རིམ་ཨང་རྟགས།</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>ཡིག་ཆའི་མིང་།</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>བཟོ་བཅོས་དུས་ཚོད།</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation>ཐོར་བའི་བརྡ་རྟགས།</translation>
    </message>
    <message>
        <source>EXE</source>
        <translation>འཕེལ་རིམ།</translation>
    </message>
    <message>
        <source>Core File</source>
        <translation>ལྟེ་བའི་ཡིག་ཆ།</translation>
    </message>
    <message>
        <source>User Name </source>
        <translation>སྤྱོད་མཁན།</translation>
    </message>
    <message>
        <source>Offset</source>
        <translation>འཕེལ་རིམ།</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>དུས་ཚོད། </translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>མ་ལག་ཉིན་ཐོ། </translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>ནང་སྙིང་ཉིན་ཐོ། </translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>འགོ་སློང་ཉིན་ཐོ། </translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg ཉིན་ཐོ། </translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin ཉིན་ཐོ། </translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg ཉིན་ཐོ། `</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>ཉེར་སྤྱོད་ཉིན་ཐོ། </translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>འཕྲུལ་སྒོ་འབྱེད་རྒྱག་བྱ་བ།</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnfཉིན་ཐོ།</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>ཉིན་ཐོ་གཞན།</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>རང་སྒྲུབ་ཉིན་ཐོ།</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>རྩིས་བཤེར་ཉིན་ཐོ།</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation>ཐོར་བའི་ཉིན་ཐོ།</translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation>ཐོར་བའི་ཆ་འཕྲིན་རག་ཐབས་བྲལ། systemd-coredumpསྒྲིག་འཇུག་བྱེད་རོགས།</translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>ལྟ་དབང་མེད།</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation>མིག་སྔའི་རྒྱུད་ཁོངས་ཀྱི་བདེ་འཇགས་རིམ་པ་ནི་མཐོ་བ་ཞེས་པ་ཡིན་པས། རྩིས་བཤེར་དོ་དམ་པ་ཁོ་ནས་རྩིས་བཤེར་ཉིན་ཐོ་ལ་བལྟས་ཆོག </translation>
    </message>
    <message>
        <source>Audit log is not exist.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation>ཉིན་ཐོ་དག་དམིགས་བཙུགས་བྱས་པའི་དཀར་ཆག་ནང་འདྲེན་པ།</translation>
    </message>
    <message>
        <source>PATH</source>
        <translation>འདྲེན་ལམ།</translation>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation>ཉིན་ཐོའི་རིགས་ལྟར་ཉིན་ཐོ་འདྲེན་པ།</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>ཉིན་ཐོའི་རིགས།</translation>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation>རང་ངོས་ཀྱིས་ཞིབ་འཇུག་བྱས་པའི་ཉེར་སྤྱོད་ལྟར་ཉིན་ཐོ་འདྲེན་པ།</translation>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation>རང་ངོས་ཀྱིས་ཞིབ་འཇུག་བྱས་པའི་མིང་།</translation>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation>དུས་ཚོད་ཀྱི་རིམ་པ་ལྟར་ཉིན་ཐོ་འདྲེན་པ།</translation>
    </message>
    <message>
        <source>PERIOD</source>
        <translation>དུས་འཁོར།</translation>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation>སྒྲིག་སྦྱོར་རིམ་པ་ལྟར་ཉིན་ཐོ་འདྲེན་པ།</translation>
    </message>
    <message>
        <source>LEVEL</source>
        <translation>སྒྲིག་སྦྱོར་རིམ་པ།</translation>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation>འགོ་སློང་རྣམ་པ།</translation>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation>རྣམ་པ་ལྟར་ཉིན་ཐོ་འགོ་སློང་བ།(klu)</translation>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation>གནས་ཚུལ་གྱི་རིགས་གཞིར་བཟུང་གནས་ཚུལ་ལམ་རྩིས་བཤེར་ཉིན་ཐོ་འདྲེན་པ།</translation>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation>གནས་ཚུལ་གྱི་རིགས།</translation>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation>བརྡ་ཆད་གཙོ་བོ་གཞིར་བཟུང་ཉིན་ཐོ་འདྲེན་པ།</translation>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation>བརྡ་ཆད་གཙོ་བོ།</translation>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation>ཐོར་སའི་ཆ་འཕྲིན་གོང་ཞུ།</translation>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation>བུ་ཆའི་དཔེ་རྣམ་ལྟར་ཉེར་སྤྱོད་ཉིན་ཐོ་འདྲེན་པ།</translation>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation>བུ་ཆའི་དཔེ་རྣམ།</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>གསར་སྒྱུར་ཕྱོད།</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>སྐར་ཆ་10རེ།</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>སྐར་མ་1རེ།</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>སྐར་མ་5</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>གསར་སྒྱུར་མི་བྱེད།</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>ཚང་མ་འདོན་པ།</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>ལམ་སེང་གསར་སྒྱུར།</translation>
    </message>
</context>
</TS>